@@ -7,7 +7,7 @@ information.
 __author__ = "Michael Stephens <mstephens@sunlightfoundation.com>"
 __copyright__ = "Copyright (c) 2011 Sunlight Labs"
 __license__ = "BSD"
-__version__ = "0.4.2"
+__version__ = "0.5.0"
 
 from remoteobjects import RemoteObject, fields, ListObject
 import urllib
@@ -16,9 +16,12 @@ OPENSTATES_URL = "http://openstates.sunlightlabs.com/api/v1/"
 
 API_KEY = ''
 
-# utility classes
 
 class OpenStateDatetime(fields.Datetime):
+    """
+    Decode timestamps of the format '2011-03-10 10:23:34'.
+    Allows value to be None.
+    """
     dateformat = '%Y-%m-%d %H:%M:%S'
 
     # None value for datetimes is fixed in trunk remoteobjects,
@@ -35,7 +38,7 @@ class OpenStateObject(RemoteObject):
         params['format'] = 'json'
         params['apikey'] = API_KEY
         url = "%s%s/?%s" % (OPENSTATES_URL, func,
-                            urllib.urlencode(params))
+                            urllib.urlencode(params, doseq=True))
         return super(OpenStateObject, cls).get(url)
 
 
@@ -50,9 +53,6 @@ class Source(OpenStateObject):
     retrieved = OpenStateDatetime()
 
 
-## Metadata
-
-
 class Term(OpenStateObject):
     start_year = fields.Field()
     end_year = fields.Field()
@@ -88,8 +88,6 @@ class State(OpenStateObject):
         return self.name
 
 
-## Bills
-
 class Action(OpenStateObject):
     date = OpenStateDatetime()
     actor = fields.Field()
@@ -140,6 +138,7 @@ class Version(OpenStateObject):
     url = fields.Field()
     name = fields.Field()
 
+
 class Document(OpenStateObject):
     url = fields.Field()
     name = fields.Field()
@@ -195,8 +194,6 @@ class Bill(OpenStateObject):
         return '%s: %s' % (self.bill_id, self.title)
 
 
-## Legislators
-
 class Role(OpenStateObject):
     state = fields.Field()
     type = fields.Field()
@@ -274,8 +271,6 @@ class Legislator(OpenStateObject):
         return self.full_name
 
 
-## Committees
-
 class CommitteeMember(OpenStateObject):
     leg_id = fields.Field()
     role = fields.Field()
@@ -289,6 +284,7 @@ class Committee(OpenStateObject):
     committee = fields.Field()
     subcommittee = fields.Field()
     members = fields.List(fields.Object(CommitteeMember))
+    sources = fields.List(fields.Object(Source))
 
     @classmethod
     def get(cls, id):
@@ -309,3 +305,25 @@ class Committee(OpenStateObject):
         For example, ``openstates.Committee.search(state='ca')``.
         """
         return ListOf(cls).get('committees', kwargs).entries
+
+
+class EventParticipant(OpenStateObject):
+    type = fields.Field()
+    participant = fields.Field()
+
+
+class Event(OpenStateObject):
+    id = fields.Field()
+    state = fields.Field()
+    description = fields.Field()
+    when = OpenStateDatetime()
+    end = OpenStateDatetime()
+    location = fields.Field()
+    type = fields.Field()
+    session = fields.Field()
+    participants = fields.List(fields.Object(EventParticipant))
+    sources = fields.List(fields.Object(Source))
+
+    @classmethod
+    def search(cls, **kwargs):
+        return ListOf(cls).get('events', kwargs).entries
